// Licensed to Apache Software Foundation (ASF) under one or more contributor
// license agreements. See the NOTICE file distributed with
// this work for additional information regarding copyright
// ownership. Apache Software Foundation (ASF) licenses this file to you under
// the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package assets

import (
	"embed"
	"strings"

	"github.com/apache/skywalking-cli/internal/logger"
)

//go:embed *
var assets embed.FS

// Read reads all content from a file under assets, which is packed in to the binary.
// It will also trim the consecutive lines starting with #.
func Read(filename string) string {
	content, err := assets.ReadFile(filename)
	if err != nil {
		logger.Log.Fatalln("failed to read asset: ", filename, err)
	}
	var lines []string
	stop := false
	for _, line := range strings.Split(string(content), "\n") {
		if !stop && strings.HasPrefix(line, "#") {
			continue
		}
		stop = true
		lines = append(lines, line)
	}

	return strings.Join(lines, "\n")
}
